{% load i18n %}
<div class="date">{{ post.date_modified|date:"M d Y" }}</div>
<h2>{{ post.title|striptags|safe }}</h2>
<p>
    {% trans 'published' %}
    {% for author in post.authors.all %}
        {% trans 'by' %}
        <a href="{% url planet_author_detail author.pk %}" title="{% trans 'See all posts for this author' %}">
            {{ author.name }}
        </a>
    {% endfor %}
    {% trans 'in' %} <a href="{% url planet_feed_detail post.feed.pk %}" title="{% trans 'See all posts for this feed' %}">
        {{ post.feed.title }}
    </a>
</p>
<ul class="original_details">
    <li>
        {% trans 'original entry' %}: <a href="{{ post.url }}">{{ post.title|safe }}</a>
    </li>
    <li>
        {% trans "in blog" %} <a href="{{ post.feed.blog.url }}">{{ post.feed.blog.title }}</a>
    </li>
</ul>
<p class="tags list">
    {% for tag in post.tags.all %}
        {% if forloop.first %} {% trans "tags" %}: {% endif %}
        <a href="{% url planet_tag_detail tag.name %}" title="Tag">{{ tag.name }}</a>{% if not forloop.last %}, {% endif %}
    {% endfor %}
</p>
