{% extends "planet/base.html" %}
{% load i18n pagination_tags %}

{% block content %}
<h2>{% trans 'Feeds talking about' %} {{ tag }}</h2>
<div class="feeds list">
    {% autopaginate feeds_list 40 %}
    {% for feed in feeds_list %}
        <p>
            <a href="{{ feed.feed_url }}" title="{% trans 'Subscribe to feed of' %} {{ feed.title }}">
                <img src="{{ MEDIA_URL }}images/feed.png" alt="Feed">
            </a>
            <a class="nombre" href="{% url planet_by_tag_feed_detail feed.pk,tag.name %}" title="{{ feed.title }}">
                {{ feed.title }}
            </a>
        </p>
    {% endfor %}
    {% paginate %}
</div>
{% endblock %}
