{% load i18n %}
{% ifnotequal feeds_list|length 1 %}
    <h4>{% trans "Feeds talking about" %} {{ tag }}</h4>
    <ul class="feeds list">
        {% for feed in feeds_list %}
            <li>
                <a class="nombre" href="{% url planet_by_tag_feed_detail feed.pk,tag.name %}" title="{{ feed.title }}">
                    {{ feed.title }}
                </a>
            </li>
        {% endfor %}
    </ul>
{% endifnotequal %}
