{% extends "planet/base.html" %}
{% load i18n pagination_tags  %}

{% block page_title %}{% trans "Blogs list" %} - {{ block.super }}{% endblock %}
{% block extrameta %}
    <meta name="DC.title" content="{% trans 'Blogs list' %} - {{ site.name }}" />
    <meta name="description" content="{% trans 'Blogs list' %} - {{ site.name }}" />
{% endblock %}

{% block content %}
<h2>{% trans "Blogs" %}</h2>
<div class="blogs list">
    {% autopaginate blogs_list 50 %}
    <ul>
    {% for blog in blogs_list %}
        <li>
            <h3>
                <a href="{{ blog.get_absolute_url }}" class="feed" title="{% trans 'See the full list of posts from this blog' %}">{{ blog.title }}</a>
            </h3>
            <ul class="blog details">
                <li>
                    {% trans 'web' %}: <a href="{{ blog.url }}" title="{% trans 'Go to the original blog' %}">{{ blog.url }}</a>
                </li>
                <li>
                    {% trans 'browse' %} <a href="{{ blog.get_absolute_url }}" class="feed" title="{% trans 'See the full list of posts from this blog' %}">{% trans 'latest posts' %}</a>
                </li>
                {% for feed in blog.feed_set.all %}
                <li>
                    {% trans 'feed' %}: <a href="{% url planet_feed_detail feed.pk %}" class="feed" title="{% trans 'See the full list of post from this feed' %}">{{ feed.title }}</a>
                    <a href="{{ feed.url }}" title="{% trans 'Subscribe to ' %} {{ feed.title }}">
                        <img src="{{ MEDIA_URL }}images/feed.png" alt="{% trans 'RSS 2.0 Feed' %}" />
                    </a>
                </li>
                {% endfor %}
            </ul>
        </li>
    {% endfor %}
    {% paginate %}
</div>
{% endblock %}
