{% load i18n %}
<ul class="feeds list">
    {% for feed in feeds_list %}
        <li>
            <a class="nombre" href="{% url planet_feed_detail feed.pk %}" title="{{ feed.title }}">
                {{ feed.title }}
            </a>
        </li>
    {% endfor %}
</ul>
