{% load i18n  %}
<h4>{% trans "Tags cloud" %}</h4>
<div class="tags cloud">
    {% for tag in tags_cloud %}
        <a href="{% url planet_tag_detail tag.name %}" class=" tag level{{ tag.font_size }}">{{ tag }}</a>
    {% endfor %}
</div>
