{% load i18n tagging_tags planet_tags %}
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
    <title>{% block page_title %}{{ site.name }}{% endblock %}</title>
    {% block extrameta %}
    <meta name="DC.title" content="{{ site.name }}" />
    {% endblock %}
    <meta http-equiv="content-language" content="en" />
    <meta http-equiv="Content-Type" content="application/xhtml+xml; charset=UTF-8">
    <link href="{{ MEDIA_URL }}icons/shortcut.ico" rel="SHORTCUT ICON">
    <link rel="meta" type="application/rdf+xml" title="FOAF" href="{% url planet_foaf %}" /> 
    <link rel="stylesheet" type="text/css" href="{{ MEDIA_URL }}css/base.css" />
    <link rel="stylesheet" type="text/css" href="{{ MEDIA_URL }}css/960.css" />
    {% block head_feeds %}
    {% endblock %}
    {% block extrastyle %}{% endblock %}
    {% block extrahead %}{% endblock %}
    <script src="{{ MEDIA_URL }}js/jquery.min.js" language="javascript"></script>
    <script language="javascript">
        function externalLinks(base_url) {
            return $('a[href^=http]:not("[href^=' + base_url + ']"):not(":has(\'img\')")');
        }
        $(document).ready(function() { externalLinks('{{ site.domain }}').addClass("external"); });
    </script>
</head>
<body>
    <div id="body-container" class="clearfix">
        <div id="header">
            <div class="logo">
                <h1>
                    <a href="{% url planet_index %}" title="{{ site.name }}">{{ site.name }}</a>
                </h1>
            </div>
            <div id="nav">
                {% block search %}
                {% endblock %}
            </div>
        </div>
        <div class="container_12">
            <div class="grid_9">
                <div class="content">
                {% block content %}
                    <!-- Your content goes here -->
                {% endblock %}
                </div>
            </div>

            <div id="right-rail" class="grid_3">
                <div id="navigation_bar">
                    {% if user.is_staff %}
                    <ul>
                        <li>
                            <a href="{% url admin:index %}">{% trans 'admin site' %}</a>
                        </li>
                    </ul>
                    {% endif %}
                    {% block menu %}
                    {% endblock %}
                </div>

                {% block right_column %}
                {% endblock %}

            </div>
        </div>
        <div id="footer">
            {% block footer %}
                <p>{% blocktrans %}Theme heavly based on the minimal and beautiful <a href="http://blog.montylounge.com/" title="Visit Mounty Lounge Industries blog">Mounty Lounge Industries blog's</a> design{% endblocktrans %}</p>
            {% endblock %}
        </div>

    </div>
</body>

</html>
