{% load i18n %}
{% ifnotequal authors|length 1 %}
<h4>{% trans "Authors talking about" %} {{ tag }}</h4>
<ul class="authors list">
    {% for author in authors %}
        <li>
            <a class="nombre" href="{% url planet_by_tag_author_detail author.pk,tag.name %}" title="{% trans 'Author of' %} {{ author.name }}">
                {{ author.name }}
            </a>
        </li>
    {% endfor %}
</ul>
{% endifnotequal %}
